@@ -1,21 +1,38 @@
 # Copyright (c) 2013 by pytest_pyramid authors and contributors
-# <see AUTHORS file>
 #
 # This module is part of pytest_pyramid and is released under
 # the MIT License (MIT): http://opensource.org/licenses/MIT
 """Pytest's fixture factories."""
 
 import os
+from typing import Dict, Any, Callable
+
 import pytest
+from _pytest.fixtures import FixtureRequest
 from webtest import TestApp
 from pyramid.config import Configurator
-try:
-    from ConfigParser import ConfigParser
-except ImportError:  # py3
-    from configparser import ConfigParser
+
+from configparser import ConfigParser
 
 
-def pyramid_config(settings=None, config_path=None):
+def _load_settings(cpath: str, io_settings: Dict[str, Any]) -> None:
+    config_parser = ConfigParser()
+    config_parser.read(cpath)
+
+    use = config_parser.get("app:main", "use")
+    if use and use.startswith("config:"):
+        base = os.path.dirname(cpath)
+        filename = use.replace("config:", "").strip()
+        sub_path = os.path.join(base, filename)
+        _load_settings(os.path.abspath(sub_path), io_settings)
+
+    for option, value in config_parser.items("app:main"):
+        io_settings[option] = value
+
+
+def pyramid_config(
+    config_path: str = None, settings: Dict[str, Any] = None
+) -> Callable[[FixtureRequest], Configurator]:
     """
     Pyramid_config fixture factory.
 
@@ -30,36 +47,28 @@ def pyramid_config(settings=None, config_path=None):
     :returns: configuration
     :rtype: `pyramid.config.Configurator`
     """
-    @pytest.fixture(scope='session')
-    def pyramid_config(request):
-        app_settings = settings
-        if app_settings is None:
 
-            def load_settings(cpath, io_settings):
-                config_parser = ConfigParser()
-                config_parser.read(cpath)
+    @pytest.fixture(scope="session")
+    def pyramid_config(request: FixtureRequest) -> Configurator:
 
-                use = config_parser.get('app:main', 'use')
-                if use and use.startswith('config:'):
-                    base = os.path.dirname(cpath)
-                    filename = use.replace('config:', '').strip()
-                    sub_path = os.path.join(base, filename)
-                    load_settings(os.path.abspath(sub_path), io_settings)
-
-                for option, value in config_parser.items('app:main'):
-                    io_settings[option] = value
-
-            # load the application settings
-            app_settings = {}
-            cpath = config_path or request.config.getvalue('pyramid_config')
-            load_settings(cpath, app_settings)
+        # load the application settings
+        app_settings: Dict[str, Any] = {}
+        if (
+            cpath := config_path
+            or request.config.getoption("pyramid_config")
+            or request.config.getini("pyramid_config")
+        ):
+            _load_settings(cpath, app_settings)
 
+        app_settings.update(settings if settings else {})
         return Configurator(settings=app_settings)
 
     return pyramid_config
 
 
-def pyramid_app(config_fixture_name, *additional_fixtures):
+def pyramid_app(
+    config_fixture_name: str, *additional_fixtures: str
+) -> Callable[[FixtureRequest], TestApp]:
     """
     pyramid_app fixture factory.
 
@@ -75,14 +84,13 @@ def pyramid_app(config_fixture_name, *additional_fixtures):
         fixture passed by  **config_fixture_name**
     :rtype: webtest.app.TestApp
     """
+
     @pytest.fixture
-    def pyramid_app(request):
+    def pyramid_app(request: FixtureRequest) -> TestApp:
         for additional_fixture in additional_fixtures:
             request.getfixturevalue(additional_fixture)
         config = request.getfixturevalue(config_fixture_name)
 
-        app = TestApp(config.make_wsgi_app())
-
-        return app
+        return TestApp(config.make_wsgi_app())
 
     return pyramid_app
